{% extends "iommi/form/file.html" %}
{% load i18n %}

{% block input %}
    <label class="file_drop_zone{% if not field.editable %} disabled{% endif %}"{% if field.editable %} data-iommi-extended-file-drop-zone{% endif %}>
        {{ field.extra_evaluated.drop_area_text }}
        {{ field.input }}
    </label>
{% endblock %}
